@@ -1,13 +1,13 @@
 // This file may be redistributed and modified only under the terms of
 // the GNU Lesser General Public License (See COPYING for details).
-// Copyright (C) 2003 Simon Goodall
+// Copyright (C) 2003-2005 Simon Goodall
 
 #define __glext_h_ 1
 #include "GL.h"
 #undef __glext_h_
 #include <string.h>
 
-#include "utility.h"
+#include <sage/utility.h>
 
 /*
  * function Taken from OpenGL FAQ
